#!/bin/sh
#  This script handles printing of files.  When printing version-extended
# names from a snapshot view, this script must fetch a copy of the version
# to print first.  This is done using 'open_file.sh' whose full pname
# should be based as the argument to '-c'.

usage() {
    echo "Usage: `basename $0` [-t tmp_file_prefix -c cmd_for_ssview] file-pname ..."
    exit 1
}

# usage
if [ $# = 0 ]; then
    usage
fi

if [ $1 = "-t" ]; then
    shift
    TMPFILE_PREFIX=$1
    if [ "$TMPFILE_PREFIX" = "" ]; then
	usage
    fi
    shift
    if [ $# = 0 ]; then
	usage
    fi
    if [ $1 != "-c" ]; then
	usage
    fi
    shift
    CMD_SSVIEW=$1
    if [ "$CMD_SSVIEW" = "" ]; then
	usage
    fi
    shift
fi

# see if "probably" in output
probably_flag=`type lpr | grep probably`
if [ "$probably_flag" = "" ]; then    
    # find printing command
    print_cmd=`type lpr | sed -n 's/lpr is \(.*\)$/\1/p'`
    if [ "$print_cmd" = "" ]; then
        print_cmd=`type lp | sed -n 's/lp is \(.*\)$/\1/p'`
    fi
    if [ "$print_cmd" = "" ]; then
        echo "Must have lp or lpr in path to print." 1>&2
        exit 1
    fi
else
    # find printing command
    pre_print_cmd=`type lpr | sed -n 's/lpr is probably \(.*\)$/\1/p'`
    if [ "$pre_print_cmd" = "" ]; then
        echo "Must have lp or lpr in path to print." 1>&2
        exit 1
    fi
    print_cmd=`echo $pre_print_cmd | sed 's/\.//'`
fi

# print each file
while [ $# -gt 0 ]; do
    pname=$1
    shift

    if [ "$TMPFILE_PREFIX" = "" ]; then
	# error if can't find file
	if [ ! -f $pname ]; then
	    echo "File not found: \"$pname.\"" 1>&2
	    continue
	fi

	# print it
	cat $pname | $print_cmd
    else
	$CMD_SSVIEW $print_cmd $TMPFILE_PREFIX $pname &
    fi
done
